# Specs

Autogenerated by docs/scripts/generate-doc-index.sh

- [docs/05-requirements/ARCHITECTURE_DECISIONS_AND_REVIEWS.md](../docs/05-requirements/ARCHITECTURE_DECISIONS_AND_REVIEWS.md)
- [docs/05-requirements/DETAILED_FUNCTIONAL_REQUIREMENTS_PART1.md](../docs/05-requirements/DETAILED_FUNCTIONAL_REQUIREMENTS_PART1.md)
- [docs/05-requirements/DETAILED_FUNCTIONAL_REQUIREMENTS_PART2.md](../docs/05-requirements/DETAILED_FUNCTIONAL_REQUIREMENTS_PART2.md)
- [docs/05-requirements/DETAILED_USER_JOURNEYS_EXTENDED.md](../docs/05-requirements/DETAILED_USER_JOURNEYS_EXTENDED.md)
- [docs/05-requirements/EXPANDED_ARCHITECTURE_DECISIONS_PART1.md](../docs/05-requirements/EXPANDED_ARCHITECTURE_DECISIONS_PART1.md)
- [docs/05-requirements/EXPANDED_UI_STATE_MODELS_PART1.md](../docs/05-requirements/EXPANDED_UI_STATE_MODELS_PART1.md)
- [docs/05-requirements/EXPANDED_USER_STORIES_PART1.md](../docs/05-requirements/EXPANDED_USER_STORIES_PART1.md)
- [docs/05-requirements/FUNCTIONAL_REQUIREMENTS.md](../docs/05-requirements/FUNCTIONAL_REQUIREMENTS.md)
- [docs/05-requirements/GRANULAR_DETAILED_REQUIREMENTS_PART1.md](../docs/05-requirements/GRANULAR_DETAILED_REQUIREMENTS_PART1.md)
- [docs/05-requirements/MASSIVELY_EXPANDED_ARCHITECTURE_COMPLETE.md](../docs/05-requirements/MASSIVELY_EXPANDED_ARCHITECTURE_COMPLETE.md)
- [docs/05-requirements/MASSIVELY_EXPANDED_USER_JOURNEYS_COMPLETE.md](../docs/05-requirements/MASSIVELY_EXPANDED_USER_JOURNEYS_COMPLETE.md)
- [docs/05-requirements/REQUIREMENTS_CHECKLIST.md](../docs/05-requirements/REQUIREMENTS_CHECKLIST.md)
- [docs/05-requirements/REQUIREMENTS_SUMMARY.md](../docs/05-requirements/REQUIREMENTS_SUMMARY.md)
- [docs/05-requirements/UI_TREE_AND_STATE_MODELS.md](../docs/05-requirements/UI_TREE_AND_STATE_MODELS.md)
- [docs/05-requirements/USER_JOURNEYS_AND_WIREFRAMES.md](../docs/05-requirements/USER_JOURNEYS_AND_WIREFRAMES.md)
- [docs/05-requirements/USER_STORIES_AND_EPICS.md](../docs/05-requirements/USER_STORIES_AND_EPICS.md)
- [docs/adr/ADR-0001-tracertm-v2-architecture.md](../docs/adr/ADR-0001-tracertm-v2-architecture.md)
- [docs/adr/ADR-0002-fastmcp-2-14-integration.md](../docs/adr/ADR-0002-fastmcp-2-14-integration.md)
- [docs/adr/ADR-0003-gherkin-bdd-parser-selection.md](../docs/adr/ADR-0003-gherkin-bdd-parser-selection.md)
- [docs/adr/ADR-0004-graph-visualization-library.md](../docs/adr/ADR-0004-graph-visualization-library.md)
- [docs/adr/ADR-0005-test-strategy-coverage-goals.md](../docs/adr/ADR-0005-test-strategy-coverage-goals.md)
- [docs/adr/ADR-0006-deployment-architecture.md](../docs/adr/ADR-0006-deployment-architecture.md)
- [docs/adr/ADR-0007-database-architecture.md](../docs/adr/ADR-0007-database-architecture.md)
- [docs/adr/ADR-0008-real-time-collaboration.md](../docs/adr/ADR-0008-real-time-collaboration.md)
- [docs/adr/ADR-0009-authentication-strategy.md](../docs/adr/ADR-0009-authentication-strategy.md)
- [docs/adr/ADR-0010-multi-language-backend.md](../docs/adr/ADR-0010-multi-language-backend.md)
- [docs/adr/ADR-0011-frontend-framework-architecture.md](../docs/adr/ADR-0011-frontend-framework-architecture.md)
- [docs/adr/ADR-0012-code-quality-enforcement.md](../docs/adr/ADR-0012-code-quality-enforcement.md)
- [docs/adr/ADR-0013-ai-agent-coordination.md](../docs/adr/ADR-0013-ai-agent-coordination.md)
- [docs/adr/ADR-0014-graph-data-structure.md](../docs/adr/ADR-0014-graph-data-structure.md)
- [docs/adr/ADR-0015-import-export-strategy.md](../docs/adr/ADR-0015-import-export-strategy.md)
- [docs/guides/viewport-graph-api-spec.md](../docs/guides/viewport-graph-api-spec.md)
- [docs/integration/ai_spec_analytics_delegation.md](../docs/integration/ai_spec_analytics_delegation.md)
- [docs/plans/2026-02-06-dependency-hardening-spec.md](../docs/plans/2026-02-06-dependency-hardening-spec.md)
- [docs/reference/ux-design-specification.md](../docs/reference/ux-design-specification.md)
- [docs/reports/viewport-api-spec-delivery.md](../docs/reports/viewport-api-spec-delivery.md)
- [docs/site/index/specs.md](../docs/site/index/specs.md)
